@@ -13,7 +13,7 @@ use Fcntl;
 use Carp qw/croak/;
 
 ## no critic (constant)
-our $VERSION = '1.008';
+our $VERSION = '1.009';
 use constant UINT32_SIZE => 4;
 
 sub new {
@@ -137,7 +137,7 @@ package Math::Random::ISAAC::PP::Embedded;
 use strict;
 use warnings;
 
-our $VERSION = '1.008';
+our $VERSION = '1.007';
 use constant {
     randrsl => 0, randcnt => 1, randmem => 2,
     randa   => 3, randb   => 4, randc   => 5,
@@ -264,7 +264,7 @@ package Math::Random::ISAAC::Embedded;
 use strict;
 use warnings;
 
-our $VERSION = '1.008';
+our $VERSION = '1.007';
 use constant _backend => 0;
 
 my %CSPRNG = (
@@ -298,7 +298,7 @@ use 5.006000;
 use Carp qw(croak);
 use Hash::Util;
 
-our $VERSION = '1.008';
+our $VERSION = '1.007';
 
 # See Math::Random::ISAAC https://rt.cpan.org/Public/Bug/Display.html?id=64324
 use constant SEED_SIZE => 256; # bits; eight 32-bit words.
@@ -346,7 +346,8 @@ sub string_from {
     my $range      = length $bag;
     croak 'Bag size must be at least one character.' unless $range;
     my $rand_bytes = q{}; # We need an empty, defined string.
-    $rand_bytes .= substr $bag, $_, 1 for @{$self->_ranged_randoms($range, $bytes)};
+    $rand_bytes .= substr $bag, $_, 1
+        for @{$self->_ranged_randoms($range, $bytes)};
     return $rand_bytes;
 }
 
